@@ -65,6 +65,7 @@ DEFAULT_CONF = {"version" : "1.2",
                 "widthsize" : "540",
                 "heightsize" : "400",
                 "maximized" : "False",
+                "latestVersionCheck" : "True",
                 "authorname" : "",
                 "authormail" : "",
               }
@@ -112,17 +113,19 @@ class Cyclograph():
         self.mygui.show()
 
         #Check if this is the latest version
-        def notify():
-            self.versionchk.stop()
-            if self.lvq.islast():
-                return
-            glal.addstatusbartext(self.mygui, _("A new version of CycloGraph is out!")+"(%s)" % self.lvq.lastversion)
-            del self.versionchk
-            del self.lvq
-        self.lvq = LastVersionQuery()
-        self.lvq.start()
-        self.versionchk = glal.Timer(10000, notify) #wait 1s before notificate
-        self.versionchk.start()
+        if self.config.getboolean("main window", "latestVersionCheck"):
+            def notify():
+                self.versionchk.stop()
+                if self.lvq.islast():
+                    return
+                glal.addstatusbartext(self.mygui, _("A new version of CycloGraph is out!")+"(%s)" % self.lvq.lastversion)
+                del self.versionchk
+                del self.lvq
+            
+            self.lvq = LastVersionQuery()
+            self.lvq.start()
+            self.versionchk = glal.Timer(10000, notify) #wait 1s before notify
+            self.versionchk.start()
 
     def init_configparser(self):
         """Create a new configparser, and inizializes with default values,
@@ -130,7 +133,7 @@ class Cyclograph():
         use this values
         """
         self.config = ConfigParser.SafeConfigParser(DEFAULT_CONF)
-        self.config.read(os.path.expanduser('~/.cyclograph.cfg'))
+        self.config.read(get_config_file_path())
 
         for sec in SECTIONS:
             if not self.config.has_section(sec):
@@ -169,12 +172,13 @@ class Cyclograph():
     def open_slope(self, event=None, filepath=None):
         """ Open a file"""
         #statusok = True
-        types = [('Supported files','*.cgx *.csv *.xml *.gpx *.kml *.tcx *.crp *.sal *.txt'),
+        types = [('Supported files','*.cgx *.csv *.xml *.gpx *.kml *.fitlog *.tcx *.crp *.sal *.txt'),
                     ('CycloGraphXml (*.cgx)', '*.cgx'),
                     ('CycloGraph (*.csv)', '*.csv'),
                     ('Ciclomaniac (*.xml)', '*.xml'),
                     ('GPS eXchange Format (*.gpx)', '*.gpx'),
                     ('Keyhole Markup Language (*.kml)', '*.kml'),
+                    ('SportTracks Fitlog files (*.fitlog)', '*.fitlog'),
                     ('Training Center xml (*.tcx)', '*.tcx'),
                     ('Ciclotour (*.crp)', '*.crp'),
                     ('Salitaker (*.sal)', '*.sal'),
@@ -205,6 +209,9 @@ class Cyclograph():
         elif filepath.lower().endswith(".kml"):
             slopefile = iofile.load_kmlfile(filepath)
             filetype = "kml"
+        elif filepath.lower().endswith(".fitlog"):
+            slopefile = iofile.load_fitlogfile(filepath)
+            filetype = "fitlog"
         elif filepath.lower().endswith(".tcx"):
             slopefile = iofile.load_tcxfile(filepath)
             filetype = "tcx"
@@ -334,7 +341,7 @@ class Cyclograph():
                     glal.addstatusbartext(self.mygui,
                                           _("Error while loading data"))
                 else:
-                    self.tabupdate(self.slopenumber_kml)
+                    self.tabupdate(self.slopenumber_kml, '*')
                     glal.enable_saving(self.mygui,  True)
                 del self.prsrthrd
             #there is nothing to update but gtk wants True
@@ -410,7 +417,7 @@ class Cyclograph():
 
     def preferences(self, event=None):
         config = ConfigParser.SafeConfigParser(DEFAULT_CONF)
-        config.read(os.path.expanduser('~/.cyclograph.cfg'))
+        config.read(get_config_file_path())
 
         for sec in SECTIONS:
             if not config.has_section(sec):
@@ -425,6 +432,7 @@ class Cyclograph():
         self.config.set("global", "theme", pref['theme'])
         self.config.set("global", "slopeinfo", str(pref['sinfo']))
         self.config.set("global", "effect-3d", str(pref['3d']))
+        self.config.set("global", "latestVersionCheck", str(pref['vcheck']))
         self.config.set("global", "authorname", unicode(pref['aname']))
         self.config.set("global", "authormail", unicode(pref['amail']))
         font = pref['fdesc']
@@ -470,8 +478,9 @@ class Cyclograph():
 
     def savepref(self, event=None):
         """Save preferences.
-        Configuration file is save in the user's home direcotory."""
-        with open(os.path.expanduser('~/.cyclograph.cfg'), "wb") as fid:
+        Configuration file is save in the user's home 
+        as standardized byXDG."""
+        with open(get_config_file_path(), "wb") as fid:
             self.config.write(fid)
 
     def defaultpref(self, event=None):
@@ -569,7 +578,7 @@ class Cyclograph():
             for i in range(1, len(slope.coords)):
                 (lat, lng)= slope.coords[i]
                 stringc += ",%s %s" % (lng, lat)
-            smap = glal.gui.Map(self.mygui, slope.name, stringc)
+            smap = glal.gui.Map(self.mygui, slope.name, stringc, save_map_image)
         else:
             glal.gui.mapcoorderr(self.mygui)
 
@@ -664,6 +673,23 @@ class Cyclograph():
             return
         page.delete_row(row_num)
 
+### Functions related to Map ###
+def save_map_image(mapwindow):
+    """ Save map to an image"""
+    formats = [("Portable Network Graphics (*.png)", "*.png"),
+               ("Bitmap (*.bmp)", "*.bmp"),
+               ("Joint Photographic Experts Group (*.jpg)", "*.jpg")]
+    filepath = ''
+    #Control if the right extension is given by user
+    while not filepath.lower().endswith(('.png', '.bmp', '.jpg')):
+        if filepath:
+            filepath += '.png'
+        filepath = glal.FileDialog(None, _("Save map"), filepath,
+                                   "", formats, glal.FD_SAVE)
+        if not filepath:
+            return
+    mapwindow.saveimage(filepath)
+
 ### Functions related to Plot ###
 def export_as_image(imgslope, settings):
     """ Save a plot to an image"""
@@ -744,7 +770,7 @@ def save_html(imgslope, settings):
     reportpage = report_html.Report_html(imgslope.name)
     reportpage.add_image(image.svg)
     if len(imgslope.coords) != 0:
-        reportpage.add_map(imgslope)
+        reportpage.add_map(imgslope, settings['width'], settings['height'])
     reportpage.addtitle(_("Slope"))
     reportpage.addtext(_("Name")+": ", imgslope.name)
     reportpage.addtext(_("Country")+": ", imgslope.country)
@@ -760,6 +786,22 @@ def save_html(imgslope, settings):
         reportpage.addnote(imgslope.comment)
     reportpage.save(filepath)
 
+def get_config_file_path():
+    config_path = os.path.expanduser(os.path.normpath('~/.config/CycloGraph'))
+    if os.environ.has_key('XDG_CONFIG_HOME') and os.path.isabs(os.environ['XDG_CONFIG_HOME']):
+        config_path = os.environ['XDG_CONFIG_HOME'] + os.path.normpath('/CycloGraph')
+    config_file = config_path +os.path.normpath('/CycloGraph.conf')
+        
+    #Create a directory if needed
+    if not os.path.exists(config_path):
+        os.makedirs(config_path)
+        #migrate old configuration file if there is any
+        old_file = os.path.expanduser(os.path.normpath('~/.cyclograph.cfg'))
+        if os.path.exists(old_file):
+            os.rename(old_file, config_file)
+        
+    return config_file
+
 def getconfig(config):
     """ Return current settings from config"""
     settings = {
@@ -767,6 +809,7 @@ def getconfig(config):
                 'theme'  : config.get("global", "theme"),
                 'sinfo'    : config.getboolean("global", "slopeinfo"),
                 '3d'    : config.getboolean("global", "effect-3d"),
+                'vcheck' : config.getboolean("global", "latestVersionCheck"),
                 'fdesc' : {
                                "des" : config.get("font", "font-des 1"),
                                "typ" : config.get("font", "font-typ 1"),
@@ -891,7 +934,8 @@ def main_cli():
     myslope.calc()
 
     config = ConfigParser.SafeConfigParser(DEFAULT_CONF)
-    config.read(os.path.expanduser('~/.cyclograph.cfg'))
+    config.read(get_config_file_path())
+    
     for sec in SECTIONS:
         if not config.has_section(sec):
             config.add_section(sec)
