@@ -20,6 +20,7 @@ import StringIO
 from gi.repository import Gtk, GObject, Gdk, GdkPixbuf, Pango
 from gi.repository import WebKit
 import glal
+import cairo
 from themes import ThemeManager
 from version import VERSION
 
@@ -211,11 +212,11 @@ class Gui(Gtk.Window):
         kmenum.set_submenu(kmenu)
 
         self.menu_item_s1 = Gtk.RadioMenuItem.new_with_label(
-                                                        [], _(u"geonames.org"))
+                                                        [], (u"geonames.org"))
         self.menu_item_s2 = Gtk.RadioMenuItem.new_with_label_from_widget(
-                                        self.menu_item_s1, _(u"earthtools.org"))
+                                        self.menu_item_s1, (u"earthtools.org"))
         self.menu_item_s3 = Gtk.RadioMenuItem.new_with_label_from_widget(
-                                            self.menu_item_s1, _(u"usgs.net"))
+                                            self.menu_item_s1, (u"usgs.net"))
 
         kmenu.append(self.menu_item_s1)
         kmenu.append(self.menu_item_s2)
@@ -232,7 +233,7 @@ class Gui(Gtk.Window):
         menubar.append(self.omenu)
 
         filemenu2 = Gtk.Menu()
-        self.amenu = Gtk.MenuItem.new_with_label(_(u"?"))
+        self.amenu = Gtk.MenuItem.new_with_label((u"?"))
         self.amenu.set_submenu(filemenu2)
 
         self.menu_item_about = Gtk.ImageMenuItem.new_from_stock(Gtk.STOCK_ABOUT, agr)
@@ -593,10 +594,10 @@ class Plot(Gtk.Window):
         rmenum = Gtk.MenuItem.new_with_mnemonic(_(u"Saving _resolution"))
         rmenum.set_submenu(rmenu)
 
-        menu_item_r1 = Gtk.RadioMenuItem.new_with_label([], _(u"800x600"))
-        menu_item_r2 = Gtk.RadioMenuItem.new_with_label_from_widget(menu_item_r1, _(u"1024x768"))
-        menu_item_r3 = Gtk.RadioMenuItem.new_with_label_from_widget(menu_item_r1, _(u"1280x800"))
-        menu_item_r4 = Gtk.RadioMenuItem.new_with_label_from_widget(menu_item_r1, _(u"1600x1200"))
+        menu_item_r1 = Gtk.RadioMenuItem.new_with_label([], (u"800x600"))
+        menu_item_r2 = Gtk.RadioMenuItem.new_with_label_from_widget(menu_item_r1, (u"1024x768"))
+        menu_item_r3 = Gtk.RadioMenuItem.new_with_label_from_widget(menu_item_r1, (u"1280x800"))
+        menu_item_r4 = Gtk.RadioMenuItem.new_with_label_from_widget(menu_item_r1, (u"1600x1200"))
         menu_item_r1.set_active(self.settings['width'] == 800)
         menu_item_r2.set_active(self.settings['width'] == 1024)
         menu_item_r3.set_active(self.settings['width'] == 1280)
@@ -717,7 +718,7 @@ class Preferences(Gtk.Dialog):
             self.colorlist.append(Gdk.Color(*components))
 
         self.default = default_pref
-        self.set_size_request(340, 380)
+        self.set_size_request(340, 400)
         notebook = Gtk.Notebook()
         notebook.set_tab_pos(Gtk.PositionType.TOP)
 
@@ -794,6 +795,16 @@ class Preferences(Gtk.Dialog):
         elif pref['serv'] == 'google elevation':
             self.serv.set_active(3)
         vbox.pack_start(self.serv, False, False, 0)
+
+        label = Gtk.Label(label="<b>"+_(u"Latest version")+"</b>")
+        label.set_use_markup(True)
+        hhbox = Gtk.HBox()
+        hhbox.pack_start(label, False, False, 0)
+        vbox.pack_start(hhbox, False, False, 5)
+        self.vcheck = Gtk.CheckButton(_(u"Check online"))
+        vbox.pack_start(self.vcheck, False, False, 0)
+        self.vcheck.set_active(pref['vcheck'])
+
         notebook.append_page(frame, Gtk.Label(label="General"))
 
         frame = Gtk.Frame()
@@ -949,6 +960,7 @@ class Preferences(Gtk.Dialog):
         self.olines.set_active(bool(self.default['orizzontal lines']))
         self.effect3d.set_active(bool(self.default['effect-3d']))
         self.showinfo.set_active(bool(self.default['slopeinfo']))
+        self.vcheck.set_active(bool(self.default['vcheck']))
         self.res.set_active(0)
         if self.default['width'] == 1600:
             self.res.set_active(3)
@@ -1039,6 +1051,7 @@ class Preferences(Gtk.Dialog):
                     'olines': self.olines.get_active(),
                     'theme' : self.theme.get_active_text(),
                     'sinfo' : self.showinfo.get_active(),
+                    'vcheck': self.vcheck.get_active(),
                     '3d'    : self.effect3d.get_active(),
                     'aname' : self.aname.get_text(),
                     'amail' : self.amail.get_text(),
@@ -1060,7 +1073,7 @@ class Preferences(Gtk.Dialog):
 
 class Map(Gtk.Dialog):
     """Show map of slopes"""
-    def __init__(self, parent, slopename, stringc):
+    def __init__(self, parent, slopename, stringc, savefnct):
         Gtk.Window.__init__(self)
 
         self.set_size_request(800, 600)#FIXME:take webpage dimension
@@ -1069,10 +1082,11 @@ class Map(Gtk.Dialog):
         self.set_resizable(True)
         self.set_type_hint(Gdk.WindowTypeHint.NORMAL)
 
+        self.savefnct = savefnct
+
         self.view = WebKit.WebView()
         sw = Gtk.ScrolledWindow()
         sw.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
-        #sw.set_placement(Gtk.CornerType.TOP_LEFT)
         sw.add(self.view)
 
         swframe = Gtk.Frame()
@@ -1081,8 +1095,14 @@ class Map(Gtk.Dialog):
         obox = Gtk.HBox()
         obox.pack_start(swframe, True, True, 0)
 
+        bbox = Gtk.HBox()
+        button_s = Gtk.Button(None, Gtk.STOCK_SAVE)
+        bbox.pack_end(button_s, False, False, 5)
+        button_s.connect("clicked", self.onsave)
+
         box = Gtk.VBox()
         box.pack_start(obox, True, True, 0)
+        box.pack_start(bbox, False, False, 5)
         vbox = self.get_content_area()
         vbox.pack_start(box, True, True, 0)
         self.show_all()
@@ -1099,6 +1119,33 @@ class Map(Gtk.Dialog):
         HTML_MAP = MAP_SCRIPT % (stringc,)
         self.view.load_html_string(HTML_MAP, "file:///")
 
+    def onsave(self, event):
+        """ Save call"""
+        self.savefnct(self)
+
+    def saveimage(self, filepath):
+        """ Save map image"""
+        winw, winh = self.get_size()
+        minviewh, viewh = self.view.do_get_preferred_height(self.view)
+        minvieww, vieww = self.view.do_get_preferred_width(self.view)
+        diff = (winw - vieww) / 2
+        dst = cairo.ImageSurface(cairo.FORMAT_ARGB32, vieww, viewh)
+        ctx = cairo.Context(dst)
+        surface = Gdk.cairo_create(self.get_window()).get_target()
+        ctx.set_source_surface(surface, -diff, -diff)
+        ctx.paint()
+
+        fformat = filepath.rsplit('.', 1)[1]
+
+        if fformat.lower() == 'png':
+            dst.write_to_png(filepath)
+        if fformat.lower() == 'bmp':
+            pixbuf = Gdk.pixbuf_get_from_surface(dst, 0, 0, vieww, viewh)
+            pixbuf.savev(filepath, "bmp", [], [])
+        if fformat.lower() == 'jpg':
+            pixbuf = Gdk.pixbuf_get_from_surface(dst, 0, 0, vieww, viewh)
+            pixbuf.savev(filepath, "jpeg", ["quality"], ["100"])
+
 
 class Create_kml(Gtk.Dialog):
     """Create kml routes"""
@@ -1216,9 +1263,10 @@ class Create_kml(Gtk.Dialog):
 
     def get_osrm(self):
         """ Returns gpx content from ORSM service"""
-        self.view.execute_script("oldtitle=document.title;document.title=document.getElementsByClassName('route-link')[1].getAttribute('onclick')")
+        self.view.execute_script("oldtitle=document.title;document.title=document.getElementsByClassName('text-link')[1].getAttribute('onclick')")
         gpxcontent = unicode(self.view.get_main_frame().get_title())
         url = gpxcontent.split('\'')
+        print(url)
         self.view.execute_script('document.title=oldtitle;')
         return self.downloadfunc(url[1])
 
