@@ -20,6 +20,7 @@ import StringIO
 import gtk
 import pango
 import webkit
+import cairo
 import glal
 from themes import ThemeManager
 from version import VERSION
@@ -211,9 +212,9 @@ class Gui(gtk.Window):
         kmenum = gtk.MenuItem("_Kml server")
         kmenum.set_submenu(kmenu)
 
-        self.menu_item_s1 = gtk.RadioMenuItem( None, _(u"geonames.org"))
-        self.menu_item_s2 = gtk.RadioMenuItem(self.menu_item_s1, _(u"earthtools.org"))
-        self.menu_item_s3 = gtk.RadioMenuItem(self.menu_item_s1, _(u"usgs.net"))
+        self.menu_item_s1 = gtk.RadioMenuItem( None, (u"geonames.org"))
+        self.menu_item_s2 = gtk.RadioMenuItem(self.menu_item_s1, (u"earthtools.org"))
+        self.menu_item_s3 = gtk.RadioMenuItem(self.menu_item_s1, (u"usgs.net"))
 
         kmenu.append(self.menu_item_s1)
         kmenu.append(self.menu_item_s2)
@@ -230,7 +231,7 @@ class Gui(gtk.Window):
         menubar.append(self.omenu)
 
         filemenu2 = gtk.Menu()
-        self.amenu = gtk.MenuItem(_(u"?"))
+        self.amenu = gtk.MenuItem((u"?"))
         self.amenu.set_submenu(filemenu2)
 
         self.menu_item_about = gtk.ImageMenuItem(gtk.STOCK_ABOUT, agr)
@@ -601,10 +602,10 @@ class Plot(gtk.Window):
         rmenum = gtk.MenuItem(_(u"Saving _resolution"))
         rmenum.set_submenu(rmenu)
 
-        menu_item_r1 = gtk.RadioMenuItem( None, _(u"800x600"))
-        menu_item_r2 = gtk.RadioMenuItem(menu_item_r1, _(u"1024x768"))
-        menu_item_r3 = gtk.RadioMenuItem(menu_item_r1, _(u"1280x800"))
-        menu_item_r4 = gtk.RadioMenuItem(menu_item_r1, _(u"1600x1200"))
+        menu_item_r1 = gtk.RadioMenuItem( None, (u"800x600"))
+        menu_item_r2 = gtk.RadioMenuItem(menu_item_r1, (u"1024x768"))
+        menu_item_r3 = gtk.RadioMenuItem(menu_item_r1, (u"1280x800"))
+        menu_item_r4 = gtk.RadioMenuItem(menu_item_r1, (u"1600x1200"))
         menu_item_r1.set_active(self.settings['width'] == 800)
         menu_item_r2.set_active(self.settings['width'] == 1024)
         menu_item_r3.set_active(self.settings['width'] == 1280)
@@ -722,7 +723,7 @@ class Preferences(gtk.Dialog):
             self.colorlist.append(gtk.gdk.Color(*components))
 
         self.default = default_pref
-        self.set_size_request(300, 380)
+        self.set_size_request(300, 480)
         notebook = gtk.Notebook()
         notebook.set_tab_pos(gtk.POS_TOP)
 
@@ -799,6 +800,16 @@ class Preferences(gtk.Dialog):
         elif pref['serv'] == 'google elevation':
             self.serv.set_active(3)
         vbox.pack_start(self.serv, False, False, 0)
+
+        label = gtk.Label("<b>"+_(u"Latest version")+"</b>")
+        label.set_use_markup(True)
+        hhbox = gtk.HBox(False, 0)
+        hhbox.pack_start(label, False, False, 0)
+        vbox.pack_start(hhbox, False, False, 5)
+        self.vcheck = gtk.CheckButton(_(u"Check online"))
+        vbox.pack_start(self.vcheck, False, False, 0)
+        self.vcheck.set_active(pref['vcheck'])
+
         notebook.append_page(frame, gtk.Label("General"))
 
         frame = gtk.Frame()
@@ -957,6 +968,7 @@ class Preferences(gtk.Dialog):
         self.olines.set_active(bool(self.default['orizzontal lines']))
         self.effect3d.set_active(bool(self.default['effect-3d']))
         self.showinfo.set_active(bool(self.default['slopeinfo']))
+        self.vcheck.set_active(bool(self.default['vcheck']))
         self.res.set_active(0)
         if self.default['width'] == 1600:
             self.res.set_active(3)
@@ -1083,6 +1095,7 @@ class Preferences(gtk.Dialog):
                     'theme' : self.theme.get_active_text(),
                     'sinfo' : self.showinfo.get_active(),
                     '3d'    : self.effect3d.get_active(),
+                    'vcheck': self.vcheck.get_active(),
                     'aname' : self.aname.get_text(),
                     'amail' : self.amail.get_text(),
                     'fdesc' : self.fdesc.desc,
@@ -1103,7 +1116,7 @@ class Preferences(gtk.Dialog):
 
 class Map(gtk.Dialog):
     """Show map of slopes"""
-    def __init__(self, parent, slopename, stringc):
+    def __init__(self, parent, slopename, stringc, savefnct):
         gtk.Window.__init__(self)
 
         self.set_size_request(640, 480)#FIXME:take webpage dimension
@@ -1112,6 +1125,8 @@ class Map(gtk.Dialog):
         self.set_resizable(True)
         self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_NORMAL)
 
+        self.savefnct = savefnct
+
         self.view = webkit.WebView()
         sw = gtk.ScrolledWindow()
         sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
@@ -1124,8 +1139,14 @@ class Map(gtk.Dialog):
         obox = gtk.HBox()
         obox.pack_start(swframe, True, True, 0)
 
+        bbox = gtk.HBox()
+        button_s = gtk.Button(None, gtk.STOCK_SAVE)
+        bbox.pack_end(button_s, False, False, 5)
+        button_s.connect("clicked", self.onsave)
+
         box = gtk.VBox(False, 0)
         box.pack_start(obox, True, True, 0)
+        box.pack_start(bbox, False, False, 5)
         self.vbox.pack_start(box)
         self.show_all()
         MAP_SCRIPT = ""
@@ -1141,6 +1162,30 @@ class Map(gtk.Dialog):
         HTML_MAP = MAP_SCRIPT % (stringc,)
         self.view.load_html_string(HTML_MAP, "file:///")
 
+    def onsave(self, event):
+        """ Save call"""
+        self.savefnct(self)
+
+    def saveimage(self, filepath):
+        """ Save map image"""
+        winw, winh = self.get_size()
+        vieww, viewh = self.view.size_request()
+        diff = (winw - vieww) / 2
+        colormap = self.get_colormap()
+        pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, 0, 8, vieww, viewh)
+        pixbuf = pixbuf.get_from_drawable(self.window, colormap,
+                                          diff, diff, 0, 0, vieww, viewh)
+
+        fformat = filepath.rsplit('.', 1)[1]
+
+        if fformat.lower() == 'png':
+            pixbuf.save(filepath, 'png')
+        if fformat.lower() == 'bmp':
+            pixbuf.save(filepath, "bmp")
+        if fformat.lower() == 'jpg':
+            pixbuf.save(filepath, "jpeg", {"quality":"100"})
+
+
 class Create_kml(gtk.Dialog):
     """Create kml routes"""
     MODE = {_(u'Open Route Service') : 'ORS',
@@ -1255,7 +1300,7 @@ class Create_kml(gtk.Dialog):
 
     def get_osrm(self):
         """ Returns gpx content from ORSM service"""
-        self.view.execute_script("oldtitle=document.title;document.title=document.getElementsByClassName('route-link')[1].getAttribute('onclick')")
+        self.view.execute_script("oldtitle=document.title;document.title=document.getElementsByClassName('text-link')[1].getAttribute('onclick')")
         gpxcontent = unicode(self.view.get_main_frame().get_title())
         url = gpxcontent.split('\'')
         self.view.execute_script('document.title=oldtitle;')
