@@ -16,6 +16,7 @@
 from __future__ import with_statement
 import csv
 import codecs
+import logging
 import os
 import xml.dom.minidom
 import zlib
@@ -134,6 +135,13 @@ def open_file(filename, slopelist, slopenum, extension=''):
             statusok = True
         except IOError:
             statusok = False
+    elif extension == 'fitlog':
+        try:
+            fitlogfile = load_fitlogfile(filename)
+            fitlogfile.newSlope(slopelist, slopenum, -1)
+            statusok = True
+        except IOError:
+            statusok = False
     elif extension == 'tcx':
         try:
             tcxfile = load_tcxfile(filename)
@@ -240,7 +248,7 @@ def __open_cgx(filename, slopelist, slopenum):
                                      , float(cpt.attributes["alt"].value)
                                      , cpt.getAttribute("desc"))
         except Exception, err:
-            print(err)
+            logging.exception(err)
             fid.unlink()
             return False
     for coord in slop.getElementsByTagName('coord'):
@@ -249,7 +257,7 @@ def __open_cgx(filename, slopelist, slopenum):
                                 float(coord.attributes["lat"].value),
                                 float(coord.attributes["lon"].value))
         except Exception, err:
-            print(err)
+            logging.exception(err)
             fid.unlink()
             return False
     fid.unlink()
@@ -340,7 +348,56 @@ def load_gpxfile(xmlfile):
         retfile.hasAltitudes = is_with_alt
         return retfile
     except Exception, err:
-        print(err)
+        logging.exception(err)
+        return None
+
+def load_fitlogfile(xmlfile):
+    """Load a fitlog file"""
+    try:
+        if isinstance(xmlfile, basestring) and xmlfile.strip().startswith('<'):
+            fid = xml.dom.minidom.parseString(xmlfile)
+        else:
+            fid = xml.dom.minidom.parse(xmlfile)
+        ptls = fid.getElementsByTagName('pt')
+        coords = [(el.attributes["lon"].value, el.attributes["lat"].value) for el in ptls]
+        cps = distance(coords)
+        next_cp = 0
+        max_dist = cps[-1][0]
+        indices = []
+        for i in range(len(cps)):
+            dist = cps[i][0]
+            if i == 0 or dist > next_cp or i == len(cps)-1:
+                indices.append(i)
+                next_cp = dist + max_dist/len(cps)
+        returncp = []
+        is_with_alt = True
+        alt_count = 0
+        name = u""
+        for i in indices:
+            #get elevation
+            (dist, lng, lat) = cps[i]
+            sample = ptls[i]
+            if sample.getAttribute('ele'):
+                elev = sample.attributes["ele"].value
+                if len(elev) > 0:
+                    alt = float(elev)
+                else:
+                    is_with_alt = False
+                    alt = 0
+            else:
+                is_with_alt = False
+                alt = 0
+            if (alt == 0):
+                alt_count += 1
+            returncp.append((dist, alt, name, lat, lng))
+        fid.unlink()
+        retfile = SlopeFile(returncp)
+        if len(indices) == alt_count:
+            is_with_alt = False
+        retfile.hasAltitudes = is_with_alt
+        return retfile
+    except Exception, err:
+        logging.exception(err)
         return None
 
 def load_kmlfile(xmlfile):
@@ -398,7 +455,7 @@ def load_kmlfile(xmlfile):
         retfile.hasAltitudes = is_with_alt
         return retfile
     except Exception, err:
-        print(err)
+        logging.exception(err)
         return None
 
 def load_tcxfile(xmlfile):
@@ -407,14 +464,21 @@ def load_tcxfile(xmlfile):
         fid = xml.dom.minidom.parse(xmlfile)
         ptls = fid.getElementsByTagName('Trackpoint')
         coords = []
+        is_with_alt = False
         for sample in ptls:
             for ent in sample.childNodes:
                 if ent.localName == "Position":
-                    lat = ent.childNodes[1].childNodes[0].data
-                    lng = ent.childNodes[3].childNodes[0].data
+                    #Iterate on child nodes to get latitude and longitude
+                    for pos_node in ent.childNodes:
+                        if pos_node.localName == "LatitudeDegrees":
+                            lat = pos_node.childNodes[0].data
+                        elif pos_node.localName == "LongitudeDegrees":
+                            lng = pos_node.childNodes[0].data
                 elif ent.localName == "AltitudeMeters":
-                    alt = ent.childNodes[0].data
-            coords.append((float(lng), float(lat), float(alt)))
+                    alt = float(ent.childNodes[0].data)
+                    if (alt != 0):
+                        is_with_alt = True
+            coords.append((lng, lat, alt))
         dist = 0.0
         (lon_old, lat_old) = point_conversion(coords[0][0], coords[0][1])
         returncp = []
@@ -423,13 +487,13 @@ def load_tcxfile(xmlfile):
             dist += haversine(lat_old, lat_new, lon_old, lon_new)
             lon_old = lon_new
             lat_old = lat_new
-            #print("lat=%s lon=%s" %(lat, lng))
             returncp.append((dist, coords[i][2], u"", coords[i][1], coords[i][0]))
         retfile = SlopeFile(returncp)
-        retfile.hasAltitudes = True
+        logging.info("is with alt " + str(is_with_alt))
+        retfile.hasAltitudes = is_with_alt
         return retfile
     except Exception, err:
-        print(err)
+        logging.exception(err)
         return None
 
 (UNSUPPORTED, CPS, AUTHOR, DATA) = range(4)
