@@ -22,7 +22,7 @@ from themes import ThemeManager
 from version import VERSION
 import StringIO
 
-if QtCore.PYQT_VERSION_STR >= '4.7':
+if QtCore.PYQT_VERSION >= 0x040700:
     iconFromTheme = QtGui.QIcon.fromTheme
 else:
     #define fallback method if using an odl version of Qt
@@ -212,6 +212,7 @@ class Preferences(QtGui.QDialog, ui_qt.Ui_Pref_Dialog):
         self.olines.setChecked(pref['olines'])
         self.effect3d.setChecked(pref['3d'])
         self.showinfo.setChecked(pref['sinfo'])
+        self.vcheck.setChecked(pref['vcheck'])
         res = 0
         if pref['width'] == 1600:
             res = 3
@@ -294,6 +295,7 @@ class Preferences(QtGui.QDialog, ui_qt.Ui_Pref_Dialog):
             self.olines.setChecked(bool(self.default['orizzontal lines']))
             self.showinfo.setChecked(bool(self.default['slopeinfo']))
             self.effect3d.setChecked(bool(self.default['effect-3d']))
+            self.vcheck.setChecked(bool(self.default['vcheck']))
             res = 0
             if self.default['width'] == 1600:
                 res = 3
@@ -403,6 +405,7 @@ class Preferences(QtGui.QDialog, ui_qt.Ui_Pref_Dialog):
                     'olines': self.olines.isChecked(),
                     'theme' : str(self.theme.currentText()),
                     'sinfo' : self.showinfo.isChecked(),
+                    'vcheck': self.vcheck.isChecked(),
                     '3d'    : self.effect3d.isChecked(),
                     'aname' : self.aname.text(),
                     'amail' : self.amail.text(),
@@ -603,11 +606,15 @@ class AnimatedPanel(QtGui.QWidget):
 
 class Map(QtGui.QDialog, ui_qt.Ui_map):
     """Show map of slopes"""
-    def __init__(self, parent, slopename, stringc):
+    def __init__(self, parent, slopename, stringc, savefnct):
         QtGui.QDialog.__init__(self, parent)
         self.setupUi(self)
+        self.savefnct = savefnct
         self.setWindowFlags(QtCore.Qt.Window)
         self.setWindowTitle(_(u"Map")+" - "+ slopename)
+        QtCore.QObject.connect(self.buttonBox,
+                               QtCore.SIGNAL("clicked(QAbstractButton *)"),
+                               self.button_clicked)
         mapfile = QtCore.QFile(":/openlayers/cyclograph/map.html")
         if mapfile.open(QtCore.QFile.ReadOnly):
             mapdata = unicode(mapfile.readAll())
@@ -615,6 +622,19 @@ class Map(QtGui.QDialog, ui_qt.Ui_map):
             mapfile.close()
             self.webView.setHtml(htmlMap)
         self.show()
+    def saveimage(self, filepath):
+        """ Save map image"""
+        page = self.webView.page()
+        img = QtGui.QImage(page.viewportSize(), QtGui.QImage.Format_ARGB32)
+        painter = QtGui.QPainter(img)
+        self.webView.render(painter)
+        painter.end()
+        img.save(filepath)
+
+    def button_clicked(self, button):
+        button_id = self.buttonBox.standardButton(button)
+        if button_id == QtGui.QDialogButtonBox.Save:
+            self.savefnct(self)
 
 class Create_kml(QtGui.QDialog, ui_qt.Ui_Create_KML_Dialog):
     """Create kml dialog"""
@@ -681,7 +701,7 @@ class Create_kml(QtGui.QDialog, ui_qt.Ui_Create_KML_Dialog):
         page = self.webView.page()
         frame = page.currentFrame()
 
-        gpxcontent = unicode(frame.evaluateJavaScript("document.getElementsByClassName('route-link')[1].getAttribute('onclick')").toString())
+        gpxcontent = unicode(frame.evaluateJavaScript("document.getElementsByClassName('text-link')[1].getAttribute('onclick')").toString())
         url = gpxcontent.split('\'')
         return self.downloadfunc(url[1])
 
