@@ -83,9 +83,7 @@ class Slope:
             self.max_grad = self.grad[0]
             for i in range(len(self.grad)):
                 if self.grad[i] > self.max_grad:
-                    self.max_grad = self.grad[i]
-                self.average_grad += self.grad[i]
-            self.average_grad = self.average_grad / len(self.grad)
+                    self.max_grad = self.grad[i]           
             self.height_gain = 0
             for i in range(len(cps)-1):
                 self.height_gain += max(cps[i+1][1]-cps[i][1], 0)
@@ -106,6 +104,9 @@ class Slope:
             #max distance is always in the last item
             self.max_d = self.cps[-1][0]
 
+            if self.max_d != 0:
+                self.average_grad = (self.cps[-1][1] - self.cps[0][1]) / (self.max_d * 10)
+
             self.dercp = self.smooth()
 
     def smooth(self):
