@@ -621,8 +621,21 @@ class ThemeBlack(Theme):
     @staticmethod
     def xaxis(devc, slope, margins, max_y, d_incr, kmsize, dx, dy):
         """Draw km bar"""
-        devc.setpen('white', 1)
-        ThemeClassic.xaxis(devc, slope, margins, max_y, d_incr, kmsize, dx, dy)
+        (updownmar, leftrightmar) = margins
+        (lef_mar, rig_mar) = leftrightmar
+        (upp_mar, low_mar) = updownmar
+        for i in range(int(slope.max_d) / d_incr - int(slope.min_d) / d_incr + 1):
+            if i % 2 == 0 :
+                devc.setbrush("rgb(0, 0, 0)")
+            else :
+                devc.setbrush("rgb(255, 255, 255)")
+            rec = (i * d_incr * kmsize + lef_mar + dx,
+                   max_y - low_mar + dy, d_incr * kmsize + 1, 5)
+            devc.setpen('black', 1)
+            devc.drawrectangle(*rec)
+            devc.setpen('white', 1)
+            d_label = ("%d" % (i * d_incr +int(slope.min_d)))
+            devc.drawtext(d_label, rec[0], rec[1] + 5)
 
     @staticmethod
     def fillhpoly(devc, points, color):
